

set -ex



apr-1-config --help
apu-1-config --help
test -f ${PREFIX}/include/apr-1/apr.h
test -f ${PREFIX}/include/apr-1/apu.h
test -f ${PREFIX}/lib/libapr-1${SHLIB_EXT}
test -f ${PREFIX}/lib/libaprutil-1${SHLIB_EXT}
test -f ${PREFIX}/lib/libapriconv-1${SHLIB_EXT}
conda inspect linkages -p ${PREFIX} apr
exit 0
